@@ -14,7 +14,7 @@ from .callbacks import ResetMetrics, SimpleBar
 from .metrics import MetricBase
 from .tasks import GeneralTaskModule
 from .callbacks import Progress
-
+from .utils import batches
 
 def default_args(func):
     signature = inspect.signature(func)
@@ -39,10 +39,12 @@ class Trainer(PLTrainer):
 
         self.init_params = default_args(PLTrainer)
         self.progress = None
+        self.best_model = None   # 训练中最好的torch模型
 
         #   *************************************
         #   *    Task Configuration    --- LIC  *
         #   *************************************
+
         metrics = self._prepare_metrics(metrics)
         if task_module is None:
             self.task_module = GeneralTaskModule(model, loss, optimizer, metrics, **task_kwargs)
@@ -117,7 +119,7 @@ class Trainer(PLTrainer):
             super().fit(self.task_module, train_dataloaders=train_dl, val_dataloaders=val_dl, ckpt_path=ckpt_path)
         return self.progress
 
-    def test(self, test_dl=None, ckpt_path='best', pl_module=None, verbose=True, metrics=None, do_loss=True):
+    def test(self, test_dl=None, ckpt_path='best', verbose=True, metrics=None, do_loss=True):  # pylint: disable=arguments-renamed
         """
         Args:
             metrics: 一旦提供了test的metrics，则会将trainer中用于test的metrics覆盖，也就是说可以指定仅用于test的metrics
@@ -129,11 +131,54 @@ class Trainer(PLTrainer):
             self.task_module.metrics['test'] = test_metrics
 
         if test_dl is not None:
-            return super().test(pl_module, dataloaders=test_dl, ckpt_path=ckpt_path, verbose=verbose)
+            return super().test(self.task_module, dataloaders=test_dl, ckpt_path=ckpt_path, verbose=verbose)
         elif self.datamodule and self.datamodule.test_dataloader():
-            return super().test(pl_module, datamodule=self.datamodule, ckpt_path=ckpt_path, verbose=verbose)
+            return super().test(self.task_module, datamodule=self.datamodule, ckpt_path=ckpt_path, verbose=verbose)
         else:
-            raise Exception("Dataloader or DataModule is needed!")
+            raise Exception("Dataloader or DataModule is needed!")  # pylint: disable=broad-exception-raised
+
+    def predict(self, pred_dl=None, has_label=False, ckpt_path='best', concat=True):  # pylint: disable=arguments-renamed
+        self.task_module.pred_dataloader_has_label = has_label
+        if pred_dl is not None:
+            preds = super().predict(self.task_module, pred_dl, None, return_predictions=True, ckpt_path=ckpt_path)
+        elif self.datamodule and self.datamodule.test_dataloader():
+            preds = super().predict(self.task_module, None, self.datamodule, return_predictions=True, ckpt_path=ckpt_path)
+        else:
+            raise Exception("Dataloader or DataModule is needed!")  # pylint: disable=broad-exception-raised
+        if concat:
+            return torch.cat(preds, dim=0)
+        else:
+            return preds
+
+    def predict_with_best(self, *inputs, batch_size=0, train=False):
+        """
+        利用最佳模型对inputs进行预测，返回预测结果
+        Args:
+            inputs: Tensor或者Tensor列表
+            batch_size: 如果batch_size == 0则不划分minibatch
+            train: 模型以训练模式(train)还是评价模式(eval)进行预测
+        """
+        if self.best_model is None:
+            self.best_model = self.restore_best()
+        if train:
+            self.best_model.train()
+        else:
+            self.best_model.eval()
+        device = next(self.best_model.parameters()).device
+
+        if batch_size > 0:
+            preds = []
+            for batch in batches(inputs, batch_size):
+                batch = batch.to(device)
+                with torch.no_grad():
+                    pred_out = self.best_model(*batch)
+                preds.append(pred_out)
+            return torch.cat(preds)
+        else:
+            with torch.no_grad():
+                inputs = [data.to(device) for data in inputs]
+                pred_out = self.best_model(*inputs)
+            return pred_out
 
     def resume_checkpoint(self, ckpt_path):
         """
@@ -163,7 +208,7 @@ class Trainer(PLTrainer):
 
     def restore_best_k(self):
         """
-        restore best k checkpoints. k is value of `save_top_k` argument in the `ModelCheckpoint` callback.
+        restore best k checkpoints. k is the value of `save_top_k` argument in the `ModelCheckpoint` callback.
         """
         best_ckp_paths = self.checkpoint_callback.best_k_models.keys()
         best_models = []
